@@ -1,14 +1,7 @@
-from unittest import skipIf
-
-import django
 from django.forms import Media
 from django.test import TestCase
 
-from js_asset.js import JS
-
-
-CSS_TYPE = ' type="text/css"' if django.VERSION < (4, 1) else ""
-JS_TYPE = ' type="text/javascript"' if django.VERSION < (3, 1) else ""
+from js_asset.js import CSS, JS, JSON
 
 
 class AssetTest(TestCase):
@@ -21,33 +14,33 @@ class AssetTest(TestCase):
                 JS("app/asset-without.js", {}),
             ],
         )
-        html = "%s" % media
+        html = str(media)
 
         # print(html)
 
         self.assertInHTML(
-            f'<link href="/static/app/print.css"{CSS_TYPE} media="print" rel="stylesheet" />',
+            '<link href="/static/app/print.css" media="print" rel="stylesheet" />',
             html,
         )
         self.assertInHTML(
-            f'<script{JS_TYPE} src="/static/app/test.js"></script>',
+            '<script src="/static/app/test.js"></script>',
             html,
         )
         self.assertInHTML(
-            f'<script{JS_TYPE} src="/static/app/asset.js" data-the-answer="42" id="asset-script"></script>',
+            '<script src="/static/app/asset.js" data-the-answer="42" id="asset-script"></script>',
             html,
         )
         self.assertInHTML(
-            f'<script{JS_TYPE} src="/static/app/asset-without.js"></script>',
+            '<script src="/static/app/asset-without.js"></script>',
             html,
         )
 
     def test_absolute(self):
-        media = Media(js=[JS("https://cdn.example.org/script.js", static=False)])
-        html = "%s" % media
+        media = Media(js=[JS("https://cdn.example.org/script.js")])
+        html = str(media)
 
         self.assertInHTML(
-            f'<script{JS_TYPE} src="https://cdn.example.org/script.js"></script>',
+            '<script src="https://cdn.example.org/script.js"></script>',
             html,
         )
 
@@ -59,14 +52,6 @@ class AssetTest(TestCase):
         self.assertEqual(media._js[0], "thing.js")
         self.assertEqual(media._js[2], "some.js")
 
-    def test_repr(self):
-        self.assertEqual(
-            repr(
-                JS("app/asset.js", {"id": "asset-script", "data-the-answer": 42})
-            ).lstrip("u"),
-            'JS(app/asset.js, {"data-the-answer": 42, "id": "asset-script"})',
-        )
-
     def test_set(self):
         media = [
             JS("app/asset.js", {"id": "asset-script", "data-the-answer": 42}),
@@ -76,12 +61,30 @@ class AssetTest(TestCase):
 
         self.assertEqual(len(set(media)), 2)
 
-    @skipIf(
-        django.VERSION < (4, 1),
-        "django-js-asset doesn't support boolean attributes yet",
-    )
     def test_boolean_attributes(self):
         self.assertEqual(
             str(JS("app/asset.js", {"bool": True, "cool": False})),
             '<script src="/static/app/asset.js" bool></script>',
         )
+
+    def test_css(self):
+        self.assertEqual(
+            str(CSS("app/style.css")),
+            '<link rel="stylesheet" href="/static/app/style.css">',
+        )
+
+        self.assertEqual(
+            str(CSS("p{color:red}", inline=True)),
+            "<style>p{color:red}</style>",
+        )
+
+    def test_json(self):
+        self.assertEqual(
+            str(JSON({"hello": "world"}, id="hello")),
+            '<script id="hello" type="application/json">{"hello": "world"}</script>',
+        )
+
+        self.assertEqual(
+            str(JSON({"hello": "world"})),
+            '<script type="application/json">{"hello": "world"}</script>',
+        )
